@@ -3,14 +3,16 @@
 START_EXTERN_C
 EXTERN_C const regexp_engine lua_engine;
 EXTERN_C REGEXP * Lua_comp(pTHX_ SV * const, U32);
-EXTERN_C I32      Lua_exec(pTHX_ REGEXP * const, char *, char *,
-                              char *, SSize_t, SV *, void *, U32);
 #if PERL_VERSION < 20
+EXTERN_C I32      Lua_exec(pTHX_ REGEXP * const, char *, char *,
+                              char *, U32, SV *, void *, U32);
 EXTERN_C char *   Lua_intuit(pTHX_ REGEXP * const, SV *, char *,
                                 char *, U32, re_scream_pos_data *);
 #else
+EXTERN_C I32      Lua_exec(pTHX_ REGEXP * const, char *, char *,
+                              char *, SSize_t, SV *, void *, U32);
 EXTERN_C char *   Lua_intuit(pTHX_ REGEXP * const, SV *, const char * const, char *,
-                                char *, U32, re_scream_pos_data *);
+                                char *, const U32, re_scream_pos_data *);
 #endif
 EXTERN_C SV *     Lua_checkstr(pTHX_ REGEXP * const);
 EXTERN_C void     Lua_free(pTHX_ REGEXP * const);
